package com.sun.tools.javac.resources;

public final class javac_zh_CN extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "javac.fullVersion", "{0}\u5B8C\u6574\u7248\u672C \"{1}\"" },
            { "javac.msg.bug", "\u7F16\u8BD1\u5668 ({0}) \u4E2D\u51FA\u73B0\u5F02\u5E38\u9519\u8BEF\u3002\u5982\u679C\u5728 Bug Database (http://bugs.java.com) \u4E2D\u6CA1\u6709\u627E\u5230\u8BE5\u9519\u8BEF\uFF0C\u8BF7\u901A\u8FC7 Java Bug \u62A5\u544A\u9875 (http://bugreport.java.com) \u5EFA\u7ACB\u8BE5 Java \u7F16\u8BD1\u5668 Bug\u3002\u8BF7\u5728\u62A5\u544A\u4E2D\u9644\u4E0A\u60A8\u7684\u7A0B\u5E8F\u3001\u4EE5\u4E0B\u8BCA\u65AD\u4FE1\u606F\u4EE5\u53CA\u4F20\u9012\u5230 Java \u7F16\u8BD1\u5668\u7684\u53C2\u6570\u3002\u8C22\u8C22\u3002" },
            { "javac.msg.io", "\n\n\u53D1\u751F\u8F93\u5165/\u8F93\u51FA\u9519\u8BEF\u3002\n\u6709\u5173\u8BE6\u7EC6\u4FE1\u606F, \u8BF7\u53C2\u9605\u4EE5\u4E0B\u5806\u6808\u8DDF\u8E2A\u3002\n" },
            { "javac.msg.parameters.output", "\u6B63\u5728\u5C06 javac \u53C2\u6570\u6253\u5370\u5230\uFF1A{0}" },
            { "javac.msg.parameters.output.error", "\u5C1D\u8BD5\u5C06 javac \u53C2\u6570\u6253\u5370\u5230 {0} \u65F6\u51FA\u9519\uFF0C\u53C2\u6570\u5C06\u91C7\u7528\uFF1A" },
            { "javac.msg.plugin.uncaught.exception", "\n\n\u63D2\u4EF6\u629B\u51FA\u672A\u6355\u83B7\u7684\u5F02\u5E38\u9519\u8BEF\u3002\n\u6709\u5173\u8BE6\u7EC6\u4FE1\u606F, \u8BF7\u53C2\u9605\u4EE5\u4E0B\u5806\u6808\u8DDF\u8E2A\u3002\n" },
            { "javac.msg.proc.annotation.uncaught.exception", "\n\n\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u629B\u51FA\u672A\u6355\u83B7\u7684\u5F02\u5E38\u9519\u8BEF\u3002\n\u6709\u5173\u8BE6\u7EC6\u4FE1\u606F, \u8BF7\u53C2\u9605\u4EE5\u4E0B\u5806\u6808\u8DDF\u8E2A\u3002\n" },
            { "javac.msg.resource", "\n\n\u7CFB\u7EDF\u8D44\u6E90\u4E0D\u8DB3\u3002\n\u6709\u5173\u8BE6\u7EC6\u4FE1\u606F, \u8BF7\u53C2\u9605\u4EE5\u4E0B\u5806\u6808\u8DDF\u8E2A\u3002\n" },
            { "javac.msg.usage", "\u7528\u6CD5: {0} <\u9009\u9879> <\u6E90\u6587\u4EF6>\n\u4F7F\u7528 --help \u53EF\u5217\u51FA\u53EF\u80FD\u7684\u9009\u9879" },
            { "javac.msg.usage.header", "\u7528\u6CD5: {0} <options> <source files>\n\u5176\u4E2D, \u53EF\u80FD\u7684\u9009\u9879\u5305\u62EC:" },
            { "javac.msg.usage.nonstandard.footer", "\u8FD9\u4E9B\u989D\u5916\u9009\u9879\u5982\u6709\u66F4\u6539, \u6055\u4E0D\u53E6\u884C\u901A\u77E5\u3002" },
            { "javac.opt.A", "\u4F20\u9012\u7ED9\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u7684\u9009\u9879" },
            { "javac.opt.AT", "\u4ECE\u6587\u4EF6\u8BFB\u53D6\u9009\u9879\u548C\u6587\u4EF6\u540D" },
            { "javac.opt.J", "\u76F4\u63A5\u5C06 <\u6807\u8BB0> \u4F20\u9012\u7ED9\u8FD0\u884C\u65F6\u7CFB\u7EDF" },
            { "javac.opt.Werror", "\u51FA\u73B0\u8B66\u544A\u65F6\u7EC8\u6B62\u7F16\u8BD1" },
            { "javac.opt.X", "\u8F93\u51FA\u989D\u5916\u9009\u9879\u7684\u5E2E\u52A9" },
            { "javac.opt.Xbootclasspath.a", "\u7F6E\u4E8E\u5F15\u5BFC\u7C7B\u8DEF\u5F84\u4E4B\u540E" },
            { "javac.opt.Xbootclasspath.p", "\u7F6E\u4E8E\u5F15\u5BFC\u7C7B\u8DEF\u5F84\u4E4B\u524D" },
            { "javac.opt.Xdoclint", "\u4E3A javadoc \u6CE8\u91CA\u4E2D\u7684\u95EE\u9898\u542F\u7528\u5EFA\u8BAE\u7684\u68C0\u67E5" },
            { "javac.opt.Xdoclint.custom", "\u4E3A javadoc \u6CE8\u91CA\u4E2D\u7684\u95EE\u9898\u542F\u7528\u6216\u7981\u7528\u7279\u5B9A\u68C0\u67E5,\n        \u5176\u4E2D <group> \u4E3A accessibility, html, missing, reference \u6216 syntax \u4E4B\u4E00\u3002\n        <access> \u4E3A public, protected, package \u6216 private \u4E4B\u4E00\u3002" },
            { "javac.opt.Xdoclint.package.args", "[-]<\u7A0B\u5E8F\u5305>(,[-]<\u7A0B\u5E8F\u5305>)*" },
            { "javac.opt.Xdoclint.package.desc", "\u5728\u7279\u5B9A\u7684\u7A0B\u5E8F\u5305\u4E2D\u542F\u7528\u6216\u7981\u7528\u68C0\u67E5\u3002\u6BCF\u4E2A <\u7A0B\u5E8F\u5305> \u662F\n\u7A0B\u5E8F\u5305\u7684\u9650\u5B9A\u540D\u79F0, \u6216\u7A0B\u5E8F\u5305\u540D\u79F0\u524D\u7F00\u540E\u8DDF '.*', \n\u5B83\u6269\u5C55\u5230\u7ED9\u5B9A\u7A0B\u5E8F\u5305\u7684\u6240\u6709\u5B50\u7A0B\u5E8F\u5305\u3002\u5728\u6BCF\u4E2A <\u7A0B\u5E8F\u5305>\n\u524D\u9762\u52A0\u4E0A '-' \u53EF\u4EE5\u4E3A\u6307\u5B9A\u7A0B\u5E8F\u5305\u7981\u7528\u68C0\u67E5\u3002" },
            { "javac.opt.Xdoclint.subopts", "(all|none|[-]<group>)[/<access>]" },
            { "javac.opt.Xlint", "\u542F\u7528\u5EFA\u8BAE\u7684\u8B66\u544A" },
            { "javac.opt.Xlint.all", "\u542F\u7528\u6240\u6709\u8B66\u544A" },
            { "javac.opt.Xlint.custom", "\u8981\u542F\u7528\u6216\u7981\u7528\u7684\u8B66\u544A, \u4F7F\u7528\u9017\u53F7\u5206\u9694\u3002\n        \u5728\u5173\u952E\u5B57\u524D\u9762\u52A0\u4E0A '-' \u53EF\u7981\u7528\u6307\u5B9A\u7684\u8B66\u544A\u3002\n        \u652F\u6301\u7684\u5173\u952E\u5B57\u5305\u62EC:" },
            { "javac.opt.Xlint.desc.auxiliaryclass", "\u6709\u5173\u8F85\u52A9\u7C7B\u5728\u6E90\u6587\u4EF6\u4E2D\u9690\u85CF, \u4F46\u5728\u5176\u4ED6\u6587\u4EF6\u4E2D\u4F7F\u7528\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.cast", "\u6709\u5173\u4F7F\u7528\u4E86\u4E0D\u5FC5\u8981\u8F6C\u6362\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.classfile", "\u6709\u5173\u4E0E\u7C7B\u6587\u4EF6\u5185\u5BB9\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.dep-ann", "\u6709\u5173\u9879\u5728 JavaDoc \u4E2D\u6807\u8BB0\u4E3A\u5DF2\u8FC7\u65F6\u4F46\u672A\u4F7F\u7528 @Deprecated \u6CE8\u91CA\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.deprecation", "\u6709\u5173\u4F7F\u7528\u4E86\u5DF2\u8FC7\u65F6\u9879\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.divzero", "\u6709\u5173\u9664\u4EE5\u5E38\u91CF\u6574\u6570 0 \u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.empty", "\u6709\u5173 if \u4E4B\u540E\u6CA1\u6709\u8BED\u53E5\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.exports", "\u6709\u5173\u4E0E\u6A21\u5757\u5BFC\u51FA\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.fallthrough", "\u6709\u5173\u4ECE switch \u8BED\u53E5\u7684\u4E00\u4E2A case \u5411\u4E0B\u987A\u5E8F\u6267\u884C\u5230\u4E0B\u4E00\u4E2A case \u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.finally", "\u6709\u5173 finally \u5B50\u53E5\u672A\u6B63\u5E38\u7EC8\u6B62\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.module", "\u6709\u5173\u6A21\u5757\u7CFB\u7EDF\u76F8\u5173\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.opens", "\u6709\u5173\u4E0E\u6A21\u5757\u6253\u5F00\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.options", "\u6709\u5173\u4E0E\u4F7F\u7528\u547D\u4EE4\u884C\u9009\u9879\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.overloads", "\u6709\u5173\u4E0E\u65B9\u6CD5\u91CD\u8F7D\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.overrides", "\u6709\u5173\u4E0E\u65B9\u6CD5\u8986\u76D6\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.path", "\u6709\u5173\u547D\u4EE4\u884C\u4E0A\u7684\u8DEF\u5F84\u5143\u7D20\u65E0\u6548\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.preview", "\u6709\u5173\u4F7F\u7528\u9884\u89C8\u8BED\u8A00\u529F\u80FD\u7684\u8B66\u544A" },
            { "javac.opt.Xlint.desc.processing", "\u6709\u5173\u4E0E\u6CE8\u91CA\u5904\u7406\u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.rawtypes", "\u6709\u5173\u4F7F\u7528\u4E86\u539F\u59CB\u7C7B\u578B\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.removal", "\u6709\u5173\u4F7F\u7528\u4E86\u6807\u8BB0\u4E3A\u5F85\u5220\u9664\u7684 API \u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.requires-automatic", "\u6709\u5173\u5728 requires \u5B50\u53E5\u4E2D\u4F7F\u7528\u81EA\u52A8\u6A21\u5757\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.requires-transitive-automatic", "\u6709\u5173 requires \u8FC7\u6E21\u4E2D\u7684\u81EA\u52A8\u6A21\u5757\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.serial", "\u6709\u5173\u672A\u63D0\u4F9B\u5E8F\u5217\u7248\u672C ID \u7684\u53EF\u5E8F\u5217\u5316\u7C7B\u7684\u8B66\u544A\u3002\n                             \u6B64\u5916\u8FD8\u8B66\u544A\u6709\u5173\u53EF\u4E32\u884C\u5316\u5143\u7D20\u5BF9\u975E\u516C\u5171\u6210\u5458\u7684\u8BBF\u95EE\u3002" },
            { "javac.opt.Xlint.desc.static", "\u6709\u5173\u4F7F\u7528\u5B9E\u4F8B\u6765\u8BBF\u95EE\u9759\u6001\u6210\u5458\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.text-blocks", "\u6709\u5173\u6587\u672C\u5757\u7F29\u8FDB\u4E2D\u7684\u7A7A\u683C\u5B57\u7B26\u4E0D\u4E00\u81F4\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.try", "\u6709\u5173\u4E0E\u4F7F\u7528 try \u5757 (\u4F8B\u5982 try-with-resources) \u76F8\u5173\u7684\u95EE\u9898\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.unchecked", "\u6709\u5173\u672A\u68C0\u67E5\u64CD\u4F5C\u7684\u8B66\u544A\u3002" },
            { "javac.opt.Xlint.desc.varargs", "\u6709\u5173\u6F5C\u5728\u4E0D\u5B89\u5168\u7684 vararg \u65B9\u6CD5\u7684\u8B66\u544A" },
            { "javac.opt.Xlint.none", "\u7981\u7528\u6240\u6709\u8B66\u544A" },
            { "javac.opt.Xstdout", "\u91CD\u5B9A\u5411\u6807\u51C6\u8F93\u51FA" },
            { "javac.opt.addExports", "\u6307\u5B9A\u88AB\u89C6\u4E3A\u5DF2\u4ECE\u5176\u5B9A\u4E49\u6A21\u5757\u5BFC\u51FA\u5230\u5176\u4ED6\u6A21\u5757\u6216\u8005\u5BFC\u51FA\u5230\u6240\u6709\n        \u672A\u547D\u540D\u6A21\u5757 (\u5982\u679C <other-module> \u4E3A ALL-UNNAMED) \u7684\u7A0B\u5E8F\u5305\u3002" },
            { "javac.opt.addReads", "\u6307\u5B9A\u88AB\u89C6\u4E3A\u7ED9\u5B9A\u6A21\u5757\u9700\u8981\u7684\u5176\u4ED6\u6A21\u5757\u3002\n<other-module> \u53EF\u80FD\u9700\u8981\u4E3A ALL-UNNAMED, \u4EE5\u4FBF\u8981\u6C42\u672A\u547D\u540D\u6A21\u5757\u3002" },
            { "javac.opt.addmods", "\u9664\u4E86\u521D\u59CB\u6A21\u5757\u4E4B\u5916\u8981\u89E3\u6790\u7684\u6839\u6A21\u5757; \u5982\u679C <module>\n        \u4E3A ALL-MODULE-PATH, \u5219\u4E3A\u6A21\u5757\u8DEF\u5F84\u4E2D\u7684\u6240\u6709\u6A21\u5757\u3002" },
            { "javac.opt.arg.Xlint", "<\u5BC6\u94A5>(,<\u5BC6\u94A5>)*" },
            { "javac.opt.arg.addExports", "<\u6A21\u5757>/<\u7A0B\u5E8F\u5305>=<\u5176\u4ED6\u6A21\u5757>(,<\u5176\u4ED6\u6A21\u5757>)*" },
            { "javac.opt.arg.addReads", "<\u6A21\u5757>=<\u5176\u4ED6\u6A21\u5757>(,<\u5176\u4ED6\u6A21\u5757>)*" },
            { "javac.opt.arg.addmods", "<\u6A21\u5757>(,<\u6A21\u5757>)*" },
            { "javac.opt.arg.class", "<class>" },
            { "javac.opt.arg.class.list", "<class1>[,<class2>,<class3>...]" },
            { "javac.opt.arg.default.module.for.created.files", "<module-name>" },
            { "javac.opt.arg.directory", "<directory>" },
            { "javac.opt.arg.dirs", "<dirs>" },
            { "javac.opt.arg.encoding", "<encoding>" },
            { "javac.opt.arg.file", "<filename>" },
            { "javac.opt.arg.flag", "<flag>" },
            { "javac.opt.arg.jdk", "<jdk>|none" },
            { "javac.opt.arg.key.equals.value", "key[=value]" },
            { "javac.opt.arg.limitmods", "<\u6A21\u5757>(,<\u6A21\u5757>)*" },
            { "javac.opt.arg.m", "<\u6A21\u5757>(,<\u6A21\u5757>)*" },
            { "javac.opt.arg.module.version", "<\u7248\u672C>" },
            { "javac.opt.arg.mspath", "<module-source-path>" },
            { "javac.opt.arg.multi-release", "<release>" },
            { "javac.opt.arg.number", "<number>" },
            { "javac.opt.arg.patch", "<\u6A21\u5757>=<\u6587\u4EF6>(:<\u6587\u4EF6>)*" },
            { "javac.opt.arg.path", "<path>" },
            { "javac.opt.arg.pathname", "<pathname>" },
            { "javac.opt.arg.plugin", "\"\u540D\u79F0\u53C2\u6570\"" },
            { "javac.opt.arg.profile", "<profile>" },
            { "javac.opt.arg.release", "<release>" },
            { "javac.opt.bootclasspath", "\u8986\u76D6\u5F15\u5BFC\u7C7B\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.classpath", "\u6307\u5B9A\u67E5\u627E\u7528\u6237\u7C7B\u6587\u4EF6\u548C\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u7684\u4F4D\u7F6E" },
            { "javac.opt.d", "\u6307\u5B9A\u653E\u7F6E\u751F\u6210\u7684\u7C7B\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.default.module.for.created.files", "\u7531\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u521B\u5EFA\u7684\u6587\u4EF6\u7684\u5907\u7528\u76EE\u6807\u6A21\u5757 (\u5982\u679C\u672A\u6307\u5B9A\u6216\u63A8\u65AD\u4EFB\u4F55\u6A21\u5757)\u3002" },
            { "javac.opt.deprecation", "\u8F93\u51FA\u4F7F\u7528\u5DF2\u8FC7\u65F6\u7684 API \u7684\u6E90\u4F4D\u7F6E" },
            { "javac.opt.diags", "\u9009\u62E9\u8BCA\u65AD\u6A21\u5F0F" },
            { "javac.opt.doclint.format", "\u6307\u5B9A\u6587\u6863\u6CE8\u91CA\u7684\u683C\u5F0F" },
            { "javac.opt.encoding", "\u6307\u5B9A\u6E90\u6587\u4EF6\u4F7F\u7528\u7684\u5B57\u7B26\u7F16\u7801" },
            { "javac.opt.endorseddirs", "\u8986\u76D6\u7B7E\u540D\u7684\u6807\u51C6\u8DEF\u5F84\u7684\u4F4D\u7F6E" },
            { "javac.opt.extdirs", "\u8986\u76D6\u6240\u5B89\u88C5\u6269\u5C55\u7684\u4F4D\u7F6E" },
            { "javac.opt.g", "\u751F\u6210\u6240\u6709\u8C03\u8BD5\u4FE1\u606F" },
            { "javac.opt.g.lines.vars.source", "\u53EA\u751F\u6210\u67D0\u4E9B\u8C03\u8BD5\u4FE1\u606F" },
            { "javac.opt.g.none", "\u4E0D\u751F\u6210\u4EFB\u4F55\u8C03\u8BD5\u4FE1\u606F" },
            { "javac.opt.headerDest", "\u6307\u5B9A\u653E\u7F6E\u751F\u6210\u7684\u672C\u673A\u6807\u5934\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.help", "\u8F93\u51FA\u6B64\u5E2E\u52A9\u6D88\u606F" },
            { "javac.opt.implicit", "\u6307\u5B9A\u662F\u5426\u4E3A\u9690\u5F0F\u5F15\u7528\u6587\u4EF6\u751F\u6210\u7C7B\u6587\u4EF6" },
            { "javac.opt.inherit_runtime_environment", "\u4ECE\u8FD0\u884C\u65F6\u73AF\u5883\u7EE7\u627F\u6A21\u5757\u7CFB\u7EDF\u914D\u7F6E\u9009\u9879\u3002" },
            { "javac.opt.limitmods", "\u9650\u5236\u53EF\u89C2\u5BDF\u6A21\u5757\u7684\u9886\u57DF" },
            { "javac.opt.m", "\u53EA\u7F16\u8BD1\u6307\u5B9A\u7684\u6A21\u5757\uFF0C\u8BF7\u68C0\u67E5\u65F6\u95F4\u6233" },
            { "javac.opt.maxerrs", "\u8BBE\u7F6E\u8981\u8F93\u51FA\u7684\u9519\u8BEF\u7684\u6700\u5927\u6570\u76EE" },
            { "javac.opt.maxwarns", "\u8BBE\u7F6E\u8981\u8F93\u51FA\u7684\u8B66\u544A\u7684\u6700\u5927\u6570\u76EE" },
            { "javac.opt.module.version", "\u6307\u5B9A\u6B63\u5728\u7F16\u8BD1\u7684\u6A21\u5757\u7248\u672C" },
            { "javac.opt.modulepath", "\u6307\u5B9A\u67E5\u627E\u5E94\u7528\u7A0B\u5E8F\u6A21\u5757\u7684\u4F4D\u7F6E" },
            { "javac.opt.modulesourcepath", "\u6307\u5B9A\u67E5\u627E\u591A\u4E2A\u6A21\u5757\u7684\u8F93\u5165\u6E90\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.moreinfo", "\u8F93\u51FA\u7C7B\u578B\u53D8\u91CF\u7684\u6269\u5C55\u4FE1\u606F" },
            { "javac.opt.multi-release", "\u6307\u5B9A\u5728\u591A\u53D1\u884C\u7248 jar \u4E2D\u4F7F\u7528\u54EA\u4E2A\u53D1\u884C\u7248" },
            { "javac.opt.nogj", "\u8BED\u8A00\u4E2D\u4E0D\u63A5\u53D7\u6CDB\u578B" },
            { "javac.opt.nowarn", "\u4E0D\u751F\u6210\u4EFB\u4F55\u8B66\u544A" },
            { "javac.opt.parameters", "\u751F\u6210\u5143\u6570\u636E\u4EE5\u7528\u4E8E\u65B9\u6CD5\u53C2\u6570\u7684\u53CD\u5C04" },
            { "javac.opt.patch", "\u4F7F\u7528 JAR \u6587\u4EF6\u6216\u76EE\u5F55\u4E2D\u7684\u7C7B\u548C\u8D44\u6E90\u8986\u76D6\n        \u6216\u589E\u5F3A\u6A21\u5757" },
            { "javac.opt.pkginfo", "\u6307\u5B9A package-info \u6587\u4EF6\u7684\u5904\u7406" },
            { "javac.opt.plugin", "\u8981\u8FD0\u884C\u7684\u63D2\u4EF6\u7684\u540D\u79F0\u548C\u53EF\u9009\u53C2\u6570" },
            { "javac.opt.prefer", "\u6307\u5B9A\u8BFB\u53D6\u6587\u4EF6, \u5F53\u540C\u65F6\u627E\u5230\u9690\u5F0F\u7F16\u8BD1\u7C7B\u7684\u6E90\u6587\u4EF6\u548C\u7C7B\u6587\u4EF6\u65F6" },
            { "javac.opt.preview", "\u542F\u7528\u9884\u89C8\u8BED\u8A00\u529F\u80FD\u3002\u8981\u4E0E -source \u6216 --release \u4E00\u8D77\u4F7F\u7528\u3002" },
            { "javac.opt.print", "\u8F93\u51FA\u6307\u5B9A\u7C7B\u578B\u7684\u6587\u672C\u8868\u793A" },
            { "javac.opt.printProcessorInfo", "\u8F93\u51FA\u6709\u5173\u8BF7\u6C42\u5904\u7406\u7A0B\u5E8F\u5904\u7406\u54EA\u4E9B\u6CE8\u91CA\u7684\u4FE1\u606F" },
            { "javac.opt.printRounds", "\u8F93\u51FA\u6709\u5173\u6CE8\u91CA\u5904\u7406\u5FAA\u73AF\u7684\u4FE1\u606F" },
            { "javac.opt.printsearch", "\u8F93\u51FA\u6709\u5173\u641C\u7D22\u7C7B\u6587\u4EF6\u7684\u4F4D\u7F6E\u7684\u4FE1\u606F" },
            { "javac.opt.proc.none.only", "\u63A7\u5236\u662F\u5426\u6267\u884C\u6CE8\u91CA\u5904\u7406\u548C/\u6216\u7F16\u8BD1\u3002" },
            { "javac.opt.processor", "\u8981\u8FD0\u884C\u7684\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u7684\u540D\u79F0; \u7ED5\u8FC7\u9ED8\u8BA4\u7684\u641C\u7D22\u8FDB\u7A0B" },
            { "javac.opt.processormodulepath", "\u6307\u5B9A\u67E5\u627E\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u7684\u6A21\u5757\u8DEF\u5F84" },
            { "javac.opt.processorpath", "\u6307\u5B9A\u67E5\u627E\u6CE8\u91CA\u5904\u7406\u7A0B\u5E8F\u7684\u4F4D\u7F6E" },
            { "javac.opt.profile", "\u8BF7\u786E\u4FDD\u4F7F\u7528\u7684 API \u5728\u6307\u5B9A\u7684\u914D\u7F6E\u6587\u4EF6\u4E2D\u53EF\u7528" },
            { "javac.opt.prompt", "\u5728\u6BCF\u6B21\u51FA\u9519\u540E\u505C\u6B62" },
            { "javac.opt.release", "\u4E3A\u6307\u5B9A\u7684 Java SE \u53D1\u884C\u7248\u7F16\u8BD1\u3002\u652F\u6301\u7684\u53D1\u884C\u7248\uFF1A{0}" },
            { "javac.opt.s", "\u53D1\u51FA java \u6E90\u800C\u4E0D\u662F\u7C7B\u6587\u4EF6" },
            { "javac.opt.source", "\u63D0\u4F9B\u4E0E\u6307\u5B9A\u7684 Java SE \u53D1\u884C\u7248\u7684\u6E90\u517C\u5BB9\u6027\u3002\u652F\u6301\u7684\u53D1\u884C\u7248\uFF1A{0}" },
            { "javac.opt.sourceDest", "\u6307\u5B9A\u653E\u7F6E\u751F\u6210\u7684\u6E90\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.sourcepath", "\u6307\u5B9A\u67E5\u627E\u8F93\u5165\u6E90\u6587\u4EF6\u7684\u4F4D\u7F6E" },
            { "javac.opt.system", "\u8986\u76D6\u7CFB\u7EDF\u6A21\u5757\u4F4D\u7F6E" },
            { "javac.opt.target", "\u751F\u6210\u9002\u5408\u6307\u5B9A\u7684 Java SE \u53D1\u884C\u7248\u7684\u7C7B\u6587\u4EF6\u3002\u652F\u6301\u7684\u53D1\u884C\u7248\uFF1A{0}" },
            { "javac.opt.upgrademodulepath", "\u8986\u76D6\u53EF\u5347\u7EA7\u6A21\u5757\u4F4D\u7F6E" },
            { "javac.opt.userpathsfirst", "\u5728\u5F15\u5BFC\u7C7B\u8DEF\u5F84\u4E4B\u524D\u800C\u4E0D\u662F\u4E4B\u540E\u641C\u7D22\u7C7B\u7684\u7C7B\u8DEF\u5F84\u548C\u6E90\u8DEF\u5F84" },
            { "javac.opt.verbose", "\u8F93\u51FA\u6709\u5173\u7F16\u8BD1\u5668\u6B63\u5728\u6267\u884C\u7684\u64CD\u4F5C\u7684\u6D88\u606F" },
            { "javac.opt.version", "\u7248\u672C\u4FE1\u606F" },
            { "javac.version", "{0} {1}" },
        };
    }
}
